summaryrefslogtreecommitdiffstats
path: root/kplato/kptcalendareditbase.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kplato/kptcalendareditbase.cc
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kplato/kptcalendareditbase.cc')
-rw-r--r--kplato/kptcalendareditbase.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kplato/kptcalendareditbase.cc b/kplato/kptcalendareditbase.cc
index e9bbd00a..aaa6fab0 100644
--- a/kplato/kptcalendareditbase.cc
+++ b/kplato/kptcalendareditbase.cc
@@ -39,11 +39,11 @@ namespace KPlato
{
/*
* Constructs a CalendarEditBase as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-CalendarEditBase::CalendarEditBase( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+CalendarEditBase::CalendarEditBase( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "CalendarEditBase" );
@@ -39,11 +39,11 @@ namespace KPlato
{
/*
- * Constructs a CalendarEditBase as a child of 'tqparent', with the
+ * Constructs a CalendarEditBase as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/